@@ -351,9 +351,10 @@ Application::Application ():
 
 		/* get the theme style for labels so that tools buttons colors might
 		be adapted to the current theme */
-		GtkWidget *w=gtk_label_new("");
-		m_Style = gtk_rc_get_style(w);
-		gtk_widget_destroy (w);
+		GtkWidget *w = gtk_label_new ("");
+		m_Style = GTK_STYLE (g_object_ref (gtk_rc_get_style (w)));
+		g_object_ref_sink (w);
+		g_object_unref (w);
 
 		// load settings before plugins
 		m_ConfNode = go_conf_get_node (GetConfDir (), GCP_CONF_DIR_SETTINGS);
@@ -451,9 +452,15 @@ Application::~Application ()
 	go_conf_free_node (m_ConfNode);
 	m_ConfNode = NULL;
 	TheThemeManager.Shutdown ();
+	g_object_unref (m_Style);
 	// unref cursors
 	for (int i = 0; i < CursorMax; i++)
 		gdk_cursor_unref (m_Cursors[i]);
+	if (m_entries)
+		g_free (RadioActions);
+	g_object_unref (IconFactory);
+	// unload plugins
+	Plugin::UnloadPlugins ();
 }
 
 void Application::ActivateTool (const string& toolname, bool activate)
@@ -468,6 +475,9 @@ void Application::ActivateTool (const string& toolname, bool activate)
 				GtkToggleToolButton* button = (GtkToggleToolButton*) ToolItems[toolname];
 				if (button && !gtk_toggle_tool_button_get_active (button))
 					gtk_toggle_tool_button_set_active (button, true);
+				Tools *ToolsBox = dynamic_cast<Tools*> (GetDialog ("tools"));
+				if (ToolsBox)
+					ToolsBox->OnSelectTool (m_pActiveTool);		
 			}
 		} else {
 			if (m_pActiveTool == m_Tools[toolname])
@@ -562,7 +572,7 @@ bool Application::FileProcess (const gchar* filename, const gchar* mime_type, bo
 		char *mess = g_strdup_printf (_("Sorry, format %s not supported!\nFailed to load %s."), mime_type, unescaped);
 		g_free (unescaped);
 		GtkWidget* message = gtk_message_dialog_new (window, GTK_DIALOG_MODAL, GTK_MESSAGE_ERROR, GTK_BUTTONS_OK, 
-													mess);
+													"%s", mess);
 		gtk_dialog_run (GTK_DIALOG (message));
 		g_free (mess);
 		gtk_widget_destroy (message);
@@ -592,7 +602,7 @@ bool Application::FileProcess (const gchar* filename, const gchar* mime_type, bo
 			char *unescaped = g_uri_unescape_string (filename2.c_str (), NULL);
 			gchar * message = g_strdup_printf (_("File %s\nexists, overwrite?"), unescaped);
 			g_free (unescaped);
-			GtkDialog* Box = GTK_DIALOG (gtk_message_dialog_new (NULL, GTK_DIALOG_MODAL, GTK_MESSAGE_QUESTION, GTK_BUTTONS_YES_NO, message));
+			GtkDialog* Box = GTK_DIALOG (gtk_message_dialog_new (NULL, GTK_DIALOG_MODAL, GTK_MESSAGE_QUESTION, GTK_BUTTONS_YES_NO, "%s", message));
 			gtk_window_set_icon_name (GTK_WINDOW (Box), "gchempaint");
 			result = gtk_dialog_run (Box);
 			gtk_widget_destroy (GTK_WIDGET (Box));
@@ -608,7 +618,7 @@ bool Application::FileProcess (const gchar* filename, const gchar* mime_type, bo
 					gchar * message = g_strdup_printf (_("Error while processing %s:\n%s"), unescaped, error->message);
 					g_free (unescaped);
 					g_error_free (error);
-					GtkDialog* Box = GTK_DIALOG (gtk_message_dialog_new (NULL, GTK_DIALOG_MODAL, GTK_MESSAGE_QUESTION, GTK_BUTTONS_YES_NO, message));
+					GtkDialog* Box = GTK_DIALOG (gtk_message_dialog_new (NULL, GTK_DIALOG_MODAL, GTK_MESSAGE_QUESTION, GTK_BUTTONS_YES_NO, "%s", message));
 					gtk_window_set_icon_name (GTK_WINDOW (Box), "gchempaint");
 					result = gtk_dialog_run (Box);
 					gtk_widget_destroy (GTK_WIDGET (Box));
