@@ -4,7 +4,7 @@
  * GChemPaint library
  * reaction.cc 
  *
- * Copyright (C) 2002-2008 Jean Bréfort <jean.brefort@normalesup.org>
+ * Copyright (C) 2002-2010 Jean Bréfort <jean.brefort@normalesup.org>
  *
  * This program is free software; you can redistribute it and/or 
  * modify it under the terms of the GNU General Public License as 
@@ -27,6 +27,7 @@
 #include "reaction-arrow.h"
 #include "reaction-step.h"
 #include "document.h"
+#include "mechanism-step.h"
 #include "molecule.h"
 #include "theme.h"
 #include "view.h"
@@ -87,8 +88,8 @@ bool Reaction::Build (list<Object*>& Children) throw (invalid_argument)
 		// Search arrows
 		if ((*i)->GetType() == ReactionArrowType)
 			Arrows.push_front ((ReactionArrow*) (*i));
-		else if ((*i)->GetType() == MoleculeType)
-			Others.push_front ((Molecule*) (*i));
+		else if ((*i)->GetType() == MoleculeType || (*i)->GetType() == MechanismStepType)
+			Others.push_front (*i);
 		else return false;
 	}
 	if (Arrows.size () == 1) {
@@ -142,6 +143,7 @@ bool Reaction::Build (list<Object*>& Children) throw (invalid_argument)
 			step = new ReactionStep (this, Left, Objects);
 			// Link fisrt step to the arrow
 			arrow->SetStartStep (step);
+			step->AddArrow (arrow);
 			// Move the arrow to its new position
 			pData->GetObjectBounds (step, &srect);
 			x0 = (srect.x0 + srect.x1) / 2;
@@ -177,6 +179,7 @@ bool Reaction::Build (list<Object*>& Children) throw (invalid_argument)
 		if (Right.size ()) {
 			step = new ReactionStep (this, Right, Objects);
 			arrow->SetEndStep (step);
+			step->AddArrow (arrow);
 			pData->GetObjectBounds (step, &srect);
 			x0 = (srect.x0 + srect.x1) / 2;
 			y0 = step->GetYAlign () * pTheme->GetZoomFactor ();
@@ -402,4 +405,9 @@ double Reaction::GetYAlign ()
 	return y;
 }
 
+std::string Reaction::Name ()
+{
+	return _("Reaction");
+}
+
 }	//	namespace gcp
