@@ -563,6 +563,7 @@ Window::Window (gcp::Application *App, char const *Theme, char const *extra_ui)
 
 Window::~Window ()
 {
+	g_object_unref (m_UIManager);
 }
 
 void Window::OnFileNew()
@@ -733,7 +734,7 @@ bool Window::VerifySaved ()
 	GtkWidget* mbox;
 	do {
 		gchar* str = g_strdup_printf (_("\"%s\" has been modified.  Do you wish to save it?"), m_Document->GetTitle ());
-		mbox = gtk_message_dialog_new (NULL, GTK_DIALOG_MODAL, GTK_MESSAGE_QUESTION, GTK_BUTTONS_YES_NO, str);
+		mbox = gtk_message_dialog_new (NULL, GTK_DIALOG_MODAL, GTK_MESSAGE_QUESTION, GTK_BUTTONS_YES_NO, "%s", str);
 		g_free (str);
 		gtk_dialog_add_button (GTK_DIALOG (mbox),  GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL);
 		res = gtk_dialog_run (GTK_DIALOG (mbox));
@@ -745,7 +746,7 @@ bool Window::VerifySaved ()
 	} while ((res == GTK_RESPONSE_YES) && (m_Document->GetFileName () == NULL));
 	if (res == GTK_RESPONSE_NO)
 		m_Document->SetDirty (false);
-	return (res != GTK_RESPONSE_CANCEL);
+	return (res == GTK_RESPONSE_YES || res == GTK_RESPONSE_NO);
 }
 
 void Window::OnPageSetup ()
